@@ -73,8 +73,9 @@ private:
 		const Glib::ustring & filename,
 		std::map< Glib::ustring, std::vector<Glib::ustring> > & map ) ;
 	Glib::ustring get_partition_path( PedPartition * lp_partition ) ;
-	void set_device_partitions( Device & device ) ;
-	GParted::FILESYSTEM get_filesystem() ; 
+	void set_device_partitions( Device & device, PedDevice* lp_device, PedDisk* lp_disk ) ;
+	GParted::FILESYSTEM get_filesystem( PedDevice* lp_device, PedPartition* lp_partition,
+	                                    std::vector<Glib::ustring>& messages ) ;
 	void read_label( Partition & partition ) ;
 	void read_uuid( Partition & partition ) ;
 	void insert_unallocated( const Glib::ustring & device_path,
@@ -84,12 +85,12 @@ private:
 				 Byte_Value sector_size,
 				 bool inside_extended ) ;
 	void set_mountpoints( std::vector<Partition> & partitions ) ;
-	void set_used_sectors( std::vector<Partition> & partitions ) ;
+	void set_used_sectors( std::vector<Partition> & partitions, PedDisk* lp_disk ) ;
 	void mounted_set_used_sectors( Partition & partition ) ;
 #ifdef HAVE_LIBPARTED_FS_RESIZE
-	void LP_set_used_sectors( Partition & partition );
+	void LP_set_used_sectors( Partition & partition, PedDisk* lp_disk ) ;
 #endif
-	void set_flags( Partition & partition ) ;
+	void set_flags( Partition & partition, PedPartition* lp_partition ) ;
 	
 	//operationstuff...
 	bool create( const Device & device, Partition & new_partition, OperationDetail & operationdetail ) ;
@@ -191,30 +192,27 @@ private:
 	bool calculate_exact_geom( const Partition & partition_old,
 			           Partition & partition_new,
 				   OperationDetail & operationdetail ) ;
-	bool set_proper_filesystem( const FILESYSTEM & filesystem ) ;
+	FileSystem* set_proper_filesystem( const FILESYSTEM & filesystem ) ;
 #ifndef HAVE_LIBPARTED_3_0_0_PLUS
 	bool erase_filesystem_signatures( const Partition & partition ) ;
 #endif
 	bool update_bootsector( const Partition & partition, OperationDetail & operationdetail ) ;
 
 	//general..	
-	bool open_device( const Glib::ustring & device_path ) ;
-	bool open_device_and_disk( const Glib::ustring & device_path, bool strict = true ) ;
-	void close_disk() ;
-	void close_device_and_disk() ;
-	bool commit() ;
-	bool commit_to_os( std::time_t timeout ) ;
+	PedDevice* open_device( const Glib::ustring & device_path ) ;
+	bool open_device_and_disk( const Glib::ustring & device_path,
+	                           PedDevice*& lp_device, PedDisk*& lp_disk, bool strict = true ) ;
+	void close_disk( PedDisk*& lp_disk ) ;
+	void close_device_and_disk( PedDevice*& lp_device, PedDisk*& lp_disk ) ;
+	bool commit( PedDisk* lp_disk ) ;
+	bool commit_to_os( PedDisk* lp_disk, std::time_t timeout ) ;
 	void settle_device( std::time_t timeout ) ;
 
 	static PedExceptionOption ped_exception_handler( PedException * e ) ;
 
 	std::vector<FS> FILESYSTEMS ;
 	std::map< FILESYSTEM, FileSystem * > FILESYSTEM_MAP ;
-	FileSystem * p_filesystem ;
 	std::vector<PedPartitionFlag> flags;
-	Glib::ustring temp ;
-	Partition partition_temp ;
-	FS fs ;
 	std::vector<Glib::ustring> device_paths ;
 	bool probe_devices ;
 	Glib::ustring thread_status_message;  //Used to pass data to show_pulsebar method
@@ -224,10 +222,6 @@ private:
 	std::map< Glib::ustring, std::vector<Glib::ustring> > fstab_info ;
 	std::map< Glib::ustring, std::vector<Glib::ustring> >::iterator iter_mp ;
 	
-	PedDevice *lp_device ;
-	PedDisk *lp_disk ;
-	PedPartition *lp_partition ;
-	
 	char * buf ;
 };
 
