@@ -131,7 +131,7 @@ void ext4::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "e2label " + partition .get_path(), output, error, true ) )
 	{
-		partition .label = Utils::trim( output ) ;
+		partition .set_label( Utils::trim( output ) ) ;
 	}
 	else
 	{
@@ -145,7 +145,7 @@ void ext4::read_label( Partition & partition )
 
 bool ext4::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "e2label " + partition .get_path() + " \"" + partition .label + "\"", operationdetail ) ;
+	return ! execute_command( "e2label " + partition .get_path() + " \"" + partition .get_label() + "\"", operationdetail ) ;
 }
 
 void ext4::read_uuid( Partition & partition )
@@ -171,7 +171,7 @@ bool ext4::write_uuid( const Partition & partition, OperationDetail & operationd
 
 bool ext4::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkfs.ext4 -j -O extent -L \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkfs.ext4 -j -O extent -L \"" + new_partition .get_label() + "\" " + new_partition .get_path(), operationdetail ) ;
 }
 
 bool ext4::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
