@@ -110,7 +110,9 @@ void nilfs2::read_label( Partition & partition )
 	{
 		Glib::ustring label = Utils::regexp_label( output, "^Filesystem volume name:[\t ]*(.*)$" ) ;
 		if ( label != "(none)" )
-			partition .label = label;
+			partition .set_label( label ) ;
+		else
+			partition .set_label( "" ) ;
 	}
 	else
 	{
@@ -124,7 +126,7 @@ void nilfs2::read_label( Partition & partition )
 
 bool nilfs2::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "nilfs-tune -L \"" + partition .label + "\" " + partition .get_path(), operationdetail ) ;
+	return ! execute_command( "nilfs-tune -L \"" + partition .get_label() + "\" " + partition .get_path(), operationdetail ) ;
 }
 
 void nilfs2::read_uuid( Partition & partition )
@@ -150,7 +152,7 @@ bool nilfs2::write_uuid( const Partition & partition, OperationDetail & operatio
 
 bool nilfs2::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	return ! execute_command( "mkfs.nilfs2 -L \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
+	return ! execute_command( "mkfs.nilfs2 -L \"" + new_partition .get_label() + "\" " + new_partition .get_path(), operationdetail ) ;
 }
 
 bool nilfs2::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
